import 'dart:convert';

import 'package:speedq_net/entities/OrderItem.dart';
import 'package:speedq_net/src/util/JsonReflector.dart';

import 'OrderStatus.dart';

@reflector
class Order {
    late String id;
    late String customerId;
    late String stallId;
    late String dateTime;
    late int code;
    late OrderStatus status;
    late _Stall stall;
    late double total;
    late List<OrderItem> items;
    late _Customer customer;

    Order.fromJson(String json) {
        Map<String, dynamic> map = jsonDecode(json);
        id = map["id"];
        customerId = map["cust_id"];
        stallId = map["stall_id"];
        dateTime = map["datetime"];
        code = map["code"];
        status = _parseJson(map["status"]);
        stall = _Stall.fromJson(map["stall"]);
        total = map["total"] is int ? (map["total"] as int).toDouble() : map["total"];
        items = (map["items"] as List).map((item) => OrderItem.fromJsonMap(item)).toList();
        customer = _Customer.fromJson(map["customer"]);
    }

    Order.fromJsonMap(Map json) {
        id = json["id"];
        customerId = json["cust_id"];
        stallId = json["stall_id"];
        dateTime = json["datetime"];
        code = json["code"];
        status = _parseJson(json["status"]);
        stall = _Stall.fromJson(json["stall"]);
        total = json["total"] is int ? (json["total"] as int).toDouble() : json["total"];
        items = (json["items"] as List).map((item) => OrderItem.fromJsonMap(item)).toList();
        customer = _Customer.fromJson(json["customer"]);
    }

    OrderStatus _parseJson(int status){
        switch(status){
            case 0: return OrderStatus.pending;
            case 1: return OrderStatus.accepted;
            case 2: return OrderStatus.rejected;
            case 3: return OrderStatus.ready;
            case 4: return OrderStatus.completed;
            default: return OrderStatus.cancelled;
        }
    }

    int _toInt(OrderStatus status){
        switch(status){
            case OrderStatus.pending: return 0;
            case OrderStatus.accepted: return 1;
            case OrderStatus.rejected: return 2;
            case OrderStatus.ready: return 3;
            case OrderStatus.completed: return 4;
            default: return 5;
        }
    }
}

class _Stall {
    late String name;
    late _FoodCourt foodCourt;

    _Stall.fromJson(Map json) {
        name = json["name"];
        foodCourt = _FoodCourt.fromJson(json["food_court"]);
    }
}

class _FoodCourt {
    late String name;

    _FoodCourt.fromJson(Map json) {
        name = json["name"];
    }
}

class _Customer {
    late String name;

    _Customer.fromJson(Map json) {
        name = json["name"];
    }
}